CheckRequest

Struct CheckRequest 

pub struct CheckRequest {
Show 20 fields pub diff_text: String, pub diff_file_path: Option<String>, pub base_ref: Option<String>, pub head_ref: Option<String>, pub lcov_texts: Vec<String>, pub lcov_paths: Vec<String>, pub max_uncovered_lines: Option<u32>, pub missing_coverage: MissingBehavior, pub missing_file: MissingBehavior, pub include_patterns: Vec<String>, pub exclude_patterns: Vec<String>, pub path_strip: Vec<String>, pub threshold_pct: f64, pub scope: Scope, pub fail_on: FailOn, pub ignore_directives: bool, pub ignored_lines: Option<BTreeMap<String, BTreeSet<u32>>>, pub sensor_schema: bool, pub output: OutputFeatureFlags, pub max_findings: Option<usize>,
}
Request for a coverage check operation.

Fields

diff_text: String

Patch file content (unified diff format).

diff_file_path: Option<String>

Path to the diff file, for report metadata.

base_ref: Option<String>

Base git ref, for report metadata (alternative to diff_file_path).

head_ref: Option<String>

Head git ref, for report metadata (alternative to diff_file_path).

lcov_texts: Vec<String>

LCOV coverage file contents (one per input).

lcov_paths: Vec<String>

Paths to LCOV files, for report metadata.

max_uncovered_lines: Option<u32>

Maximum allowed uncovered lines (optional tolerance buffer).

missing_coverage: MissingBehavior

How to handle missing coverage lines within files.

missing_file: MissingBehavior

How to handle files with no coverage data.

include_patterns: Vec<String>

Glob patterns to include (allowlist).

exclude_patterns: Vec<String>

Glob patterns to exclude.

path_strip: Vec<String>

Prefixes to strip from LCOV SF paths.

threshold_pct: f64

Minimum diff coverage percentage threshold.

scope: Scope

Scope of lines to evaluate.

fail_on: FailOn

Determines when the evaluation should fail.

ignore_directives: bool

Whether to honor covguard: ignore directives.

ignored_lines: Option<BTreeMap<String, BTreeSet<u32>>>

Pre-computed ignored lines (path -> set of line numbers). If provided, these are used directly instead of reading from source.

sensor_schema: bool

Emit sensor.report.v1 schema with capabilities block.

output: OutputFeatureFlags

Renderer budgets used for markdown/annotations/SARIF output.

max_findings: Option<usize>

Maximum number of findings to include in the report (truncation).